from setuptools import setup

setup(
	name='downloaderlib',
    version='2.1',
    description='This library is for downloading images, GitHub files, etc.',
    packages=['downloaderlib'],
   author_email='0nameofshadow0@gmail.com',
    install_requires=["urllib3","requests"])